diff mplayer.c @ 1772:591398376329

stop/pause/seek gui
author arpi
date Thu, 30 Aug 2001 12:47:13 +0000
parents b3f6e2baffbf
children de6a0987a08d
line wrap: on
line diff
--- a/mplayer.c	Thu Aug 30 12:19:52 2001 +0000
+++ b/mplayer.c	Thu Aug 30 12:47:13 2001 +0000
@@ -1498,7 +1498,7 @@
 #ifdef HAVE_NEW_GUI
              if(use_gui){
 		wsHandleEvents();mplTimerHandler(0); // handle GUI timer events
-		if(mplShMem->Playing!=2) break; // end of pause
+		if(mplShMem->Playing!=2 || (rel_seek_secs || abs_seek_pos)) break; // end of pause or seek
              }
 #endif
              if(use_stdin) usec_sleep(1000); // do not eat the CPU
@@ -1769,14 +1769,8 @@
 	}
 	mplShMem->TimeSec=d_video->pts; 
 	printf("mplShMem->Playing=%d  \n",mplShMem->Playing);
-	switch(mplShMem->Playing){
-	case 0: // stop
-//	  osd_function=OSD_PAUSE;break;
-	case 1: // play
-	  break;
-	case 2: // pause
-	  osd_function=OSD_PAUSE;break;
-	}
+	if(mplShMem->Playing==0) break; // STOP
+	if(mplShMem->Playing==2) osd_function=OSD_PAUSE;
       }
 #endif